@@ -111,6 +111,12 @@ class Container:
         for chain in self.PeptideChains.keys():
             for res in self.PeptideChains[chain].values():
                 res.CalculateCentroid()
+        for chain in self.DNAChains.keys():
+            for res in self.DNAChains[chain].values():
+                res.CalculateCentroid()
+        for chain in self.RNAChains.keys():
+            for res in self.RNAChains[chain].values():
+                res.CalculateCentroid()
         pass
 
 
@@ -160,4 +166,4 @@ class Container:
                 fullLst = fullLst + list(val.values())
         for val in fullLst:
             retLst = retLst + list(val.values())
-        return sorted(retLst, key=lambda val : val.number) if ordered else retLst
+        return sorted(retLst, key=lambda val : val.seqNum) if ordered else retLst
