@@ -43,6 +43,10 @@ class HETATM:
     def ClearFlags(self):
         self.flags.clear()
 
+    def GetType(self):
+        return "HETATM"
+
+    #TODO Standardize this so that it functions correctly when inheriting from residue base class
     def CalculateCentroid(self):
         if 'atoms' not in self.__dict__:
             self.centroid = None
