@@ -15,14 +15,31 @@ class PDB:
     def Contents(self):
         return self.container
 
-    def Fetch(self, prot, crash = True):
+    def FetchFASTA(self, prot):
+        import urllib.request
+        url = r"https://www.rcsb.org/fasta/entry/" + prot.strip().upper() + r"/display"
+        try:
+            with urllib.request.urlopen(url) as f:
+                return f.read().decode('utf-8')
+        except urllib.error.URLError:
+            sys.stderr.write("The requested pdb code could not be retrieved or does not exist\n")
+            return False
+
+    # def FetchAsFile(self, prot):
+    #     import urllib.request
+    #     url = r'https://files.rcsb.org/download/' + prot.strip() + '.pdb'
+    #     try:
+    #         with urllib.request.urlopen(url) as f:
+
+
+    def Fetch(self, prot, crash = True, hold_pdb=False):
         # print("Fetching ", prot)
         import urllib.request
         url = r'https://files.rcsb.org/download/' + prot.strip() + '.pdb'
         try:
             with urllib.request.urlopen(url) as f:
                 self.container.SetFetch(f.read().decode('utf-8'))
-                self._Parse()
+                self._Parse(hold_pdb)
                 return True
         except urllib.error.URLError:
             sys.stderr.write("The requested pdb code could not be retrieved or does not exist\n")
@@ -30,26 +47,29 @@ class PDB:
                 exit()
             return False
 
-    def Read(self, path):
+    def Read(self, path, hold_pdb=False):
         with open(path, 'r') as fp:
             self.container.SetFetch(fp.read())
-            self._Parse()
+            self._Parse(hold_pdb)
 
     # Wrapper for the ParsePDB file to allow functionality with a fetched protein
-    def _Parse(self):
+    def _Parse(self, hold_pdb=False):
         try:
             if self.container.GetFetch() is None:
                 raise apaExcept.NoFetchError
-            return self._ParsePDB(self.container.GetFetch())
+            return self._ParsePDB(self.container.GetFetch(), hold_pdb)
             # return self._ParsePDB(self.container.GetFetch().splitlines())
         except apaExcept.NoFetchError as e:
             sys.stderr.write(e.message)
 
 
     #PDB standard described here: https://www.wwpdb.org/documentation/file-format-content/format33/v3.3.html
-    def _ParsePDB(self, raw_pdb):
+    def _ParsePDB(self, raw_pdb, hold_pdb=False):
         self.container.ClearAll()
+        if hold_pdb:
+            self.container.SetFetch(raw_pdb)
         for line in raw_pdb.splitlines():
+            # print(line)
             if line[0:6] == 'ATOM  ' or line[0:6] == 'HETATM':
                 self._ParseAtomHETATM(line)
             #TODO Parse REMARK 350 to get symmetry information
@@ -74,7 +94,10 @@ class PDB:
         atom = Atom.Atom(serial=serial, name=name, altLoc=altLoc, resName=resName, chainID=chainID, resSeq=resSeq,
                          iCode=iCode, x=x, y=y, z=z, occupancy=occupancy, tempFactor=tempFactor, element=element,
                          charge=charge)
-        resType = self.DetermineResType(resName)
+        if "HETATM" in line:
+            resType = "HETATM"
+        else:
+            resType = self.DetermineResType(resName)
         residue = self.container.AddResidue(resType, resSeq, resName, chainID)
         residue.InsertAtom(atom)
 
@@ -106,3 +129,15 @@ class PDB:
         with open(fp, "w") as f:
             for res in s:
                 f.write(res.WriteForPDB())
+
+    #Write contents to FASTA
+    def ToFASTA(self):
+        ls = self.container.AsList(ordered=True)
+        retStr = ""
+        for r in ls:
+            if data.ValidateAA(r.resName):
+                name = data.Map("Amino Acids", r.resName)
+                retStr += data.GetJson()["Amino Acids"][name]["1code"]
+            elif r.resName.upper() != "HOH":
+                retStr += "X"
+        return retStr
\ No newline at end of file
